/**
    Se da un sir a[] cu n elem.
    Sa se raspunda la Q query-uri de forma:
    0 i v  (a[i] += v)  => update
    1 i j  suma(a[i], ..., a[j])

    Fenwick Trees (Binary Indexed Trees)
    Complexitate: O(log2(n)) / query
*/

#include <fstream>
using namespace std;

ifstream fin("aib.in");
ofstream fout("aib.out");

const int N = 100000;
int b[N];   // arborele indexat binar
int n, Q;

// returneaza suma a[1] + ... + a[p]
int Query(int p)  // O(log(n))
{
    int sum = 0;
    for (int i = p; i; i -= i & -i)
        sum += b[i];
    return sum;
}

void Update(int p, int v)  // O(log2(n)
{
    for (int i = p; i <= n; i += i & -i)
        b[i] += v;
}

int main()
{
    // O((n + Q) * log2(n))
    int val;
    fin >> n >> Q;
    for (int i = 1; i <= n; ++i)  // O(n * log2(n))
    {
        fin >> val;;
        Update(i, val);  // introducem valorile initiale in AIB
    }

    int i, v, j, type;
    while (Q--)   // O(Q * log2(n))
    {
        fin >> type;
        if (type == 0)  // update
        {
            fin >> i >> v;
            Update(i, v);
        }
        else            // query
        {
            fin >> i >> j;
            fout << Query(j) - Query(i - 1) << '\n';
        }
    }
}
